@@ -27,6 +27,7 @@ constants.TELEMETRY_SDK_VERSION = __version__
 class Agent(agent.Agent):
     def __init__(self):
         super().__init__()
+        self.is_lambda = False
         logger.debug("Platform: %s", distro.id())
         logger.debug("Platform version: %s", distro.version())
         logger.debug('TraceableAI Agent version: %s', __version__)
@@ -51,20 +52,23 @@ class Agent(agent.Agent):
 
 
     def add_traceable_filter(self):  #pylint:disable=R0201
-        # We need to do a local import so that the extension is not loaded in a parent process
-        from traceableai.filter.traceable import Traceable, _BLOCKING_AVAILABLE  # pylint:disable=C0413,C0412,C0415
         logger.debug("in add_traceable_filter")
         if distro.id() == 'alpine':
-            logger.info('blocking unavailable on alpine linux, skipping filter registration')
+            logger.info('libtraceable unavailable on alpine linux, skipping filter registration')
             return
-        if not _BLOCKING_AVAILABLE:
-            logger.info("blocking unavailable, skipping filter registration")
+        if self.is_lambda:
+            logger.info('Not loading blocking extension - currently unsupported in lambda')
+            return
+        # We need to do a local import so that the extension is not loaded in a parent process
+        from traceableai.filter.traceable import Traceable, _LIBTRACEABLE_AVAILABLE  # pylint:disable=C0413,C0412,C0415
+        if not _LIBTRACEABLE_AVAILABLE:
+            logger.info("libtraceable unavailable, skipping filter registration")
             return
         if Config().config.blocking_config.enabled.value is not True:
-            logger.info("Not adding blocking filter - blocking is not enabled")
+            logger.info("Not adding libtraceable filter - blocking is not enabled")
             return
         try:
             Registry().register(Traceable)
             logger.debug("successfully initialized traceable filter")
         except: # pylint:disable=W0702
-            logger.info("failed to register traceable blocking filter")
+            logger.info("failed to register traceable filter")
