@@ -1,24 +1,26 @@
-# Allow use of TA_ env vars instead of HT_
 import os
 
 import psutil
+# Allow use of TA_ env vars instead of HT_
 from hypertrace import env_var_settings
-from traceableai.agent import Agent
-
 env_var_settings.ENV_VAR_PREFIXES.append('TA')
-
-# This will initialize the hypertrace instrumentation
-a = Agent()
-import hypertrace.agent.autoinstrumentation.sitecustomize # pylint:disable=C0413,W0611,C0411
-
+from traceableai.agent import Agent # pylint:disable=C0413
 
 from traceableai.config.config import Config  # pylint:disable=C0413,C0412
-
 from hypertrace.agent.custom_logger import get_custom_logger  # pylint:disable=C0413,C0412,C0411
 
 config = Config()
 logger = get_custom_logger(__name__)
 
+# if using AWS_LAMBDA_EXEC_WRAPPER we will invoke instrumentation here
+# and skip it in our wrapper handler
+# otherwise(on py3.6 + 3.7) instrumentation + processor registration will occur within our wrapper handler
+a = Agent()
+if "_HANDLER" in os.environ:
+    a.is_lambda = True
+
+a.instrument(None, None, auto_instrument=True)
+
 __POST_INIT = False
 POST_FORK_SERVERS = ['gunicorn']
 
